OpenTAXII
============

Intelworks Python TAXII server implementation.

:Source: https://github.com/Intelworks/OpenTAXII
:Documentation: http://opentaxii.readthedocs.org
:Information: http://www.intelworks.com
:Download: https://pypi.python.org/pypi/opentaxii/

|travis badge| |landscape.io badge| |coveralls.io badge| |version badge| |py.version badge| |downloads badge| |license badge| |docs badge|

.. |travis badge| image:: https://travis-ci.org/Intelworks/OpenTAXII.svg?branch=master
   :target: https://travis-ci.org/Intelworks/OpenTAXII
   :alt: Build Status
.. |landscape.io badge| image:: https://landscape.io/github/Intelworks/OpenTAXII/master/landscape.svg?style=flat
   :target: https://landscape.io/github/Intelworks/OpenTAXII/master
   :alt: Code Health
.. |coveralls.io badge| image:: https://coveralls.io/repos/Intelworks/OpenTAXII/badge.svg
   :target: https://coveralls.io/r/Intelworks/OpenTAXII
   :alt: Coverage Status
.. |version badge| image:: https://pypip.in/version/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/ 
.. |py.version badge| image:: https://pypip.in/py_versions/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/ 
.. |downloads badge| image:: https://pypip.in/download/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/
.. |license badge| image:: https://pypip.in/license/opentaxii/badge.svg?style=flat
   :target: https://pypi.python.org/pypi/opentaxii/
.. |docs badge| image:: https://readthedocs.org/projects/opentaxii/badge/?version=latest
    :alt: Documentation Status
    :scale: 100%
    :target: https://readthedocs.org/projects/opentaxii/

OpenTAXII is a robust Python implementation of TAXII Services that 
delivers rich feature set and friendly pythonic API built on top of 
well designed application.


Feedback
--------

You are encouraged to provide feedback by commenting on open issues or sending us 
email at opentaxii@intelworks.com 
